@@ -1,6 +1,10 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
+Print(functionName.__doc__) to see the 
+
+documentation for the function or usage.
+
 Send enquiries to osita@protein-science.com
 """
 import os
@@ -44,7 +48,7 @@ def exitNotes(resNo,chain):
     -------
     None:    a premature termination of the program
     """
-    with open('missing_backbone_atom.txt', 'a') as f:
+    with open('missing_backbone_atom.txt', 'w') as f:
         f.write('The residue No {} in chain {} is missing'
             ' backbone heavy atom. Program has terminated'
             ' abnormally'.format(resNo,chain)+'\n\n')
@@ -59,7 +63,7 @@ def exitError():
     -------
     None:   a premature termination of the program
     """
-    with open('invalid_pdb_file.txt', 'a') as f:
+    with open('invalid_pdb_file.txt', 'w') as f:
         f.write('Error occured while reading the PDB file'+'\n')
         f.write('Visit www.protein-science.com to see what PRAS expects')
         sys.exit()
@@ -90,7 +94,6 @@ def checkpdbAtoms (pdb_pras,rotamer,mutation,pdb_faspr):
     A list:    a list that contains all chains with complete heavy atom of each residue
     """
 
-
     for i in os.listdir(os.getcwd()):
         if i == 'log.txt': 
             os.remove(i)
@@ -99,15 +102,19 @@ def checkpdbAtoms (pdb_pras,rotamer,mutation,pdb_faspr):
           
     with open('log.txt', 'a') as log:
 
-        log.write('Please cite this program as "O.S. Nnyigide, T.O. Nnyigide,' 
-        ' S.G. Lee, K. Hyun. PRAS: A Web Server to Repair PDB Files,'+'\n' 
-        'Add Missing Heavy Atoms and Hydrogen Atoms and Assign'
-        ' Secondary Structure by Amide Interactions. To be Submitted'+'\n')
+        log.write('When using files generated by this program in a publication'
+        ' please cite this program as "O.S. Nnyigide, T.O. Nnyigide,'+'\n' 
+        'S.G. Lee, K. Hyun. PRAS: A Web Server to Repair PDB Files,' 
+        ' Add Missing Heavy Atoms and Hydrogen Atoms and Assign'+'\n'
+        'Secondary Structure by Amide Interactions. Submitted'+'\n')
         log.write('#'*118+'\n')        
-        log.write('PRAS 1.0. This is a PRAS-generated log file.' 
+        log.write('PRAS 1.0.1 This is a PRAS-generated log file.' 
                 ' For your information, fixed atoms (if any) are appended below '+'\n')
         log.write('#'*118+'\n\n')
- 
+
+    """read user's input file obtained from faspr
+        but if it is not readable inform the user and
+        use default chi from Dunbrack 2011 rotamer library"""
     try:
         faspr = getChains("","","",pdb_faspr)
     except:
@@ -116,9 +123,16 @@ def checkpdbAtoms (pdb_pras,rotamer,mutation,pdb_faspr):
     if not faspr:
         with open('log.txt', 'a') as log:
             log.write('No FASPR PDB output supplied. Default chi will be used'+'\n\n')
+
+    """read user's input file to be repaired or analyzed
+        but if it is not readable inform the user and
+        terminate the program"""
     try:
         chains = getChains(pdb_pras,rotamer,mutation,"")
     except:
+        chains = []
+
+    if not chains:
         exitError()
 
     for n in range(len(chains)):
