@@ -1,6 +1,10 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
+Print(functionName.__doc__) to see the 
+
+documentation for the function or usage.
+
 Send enquiries to osita@protein-science.com
 """
 import numpy as np
