@@ -1,6 +1,10 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
+Print(functionName.__doc__) to see the 
+
+documentation for the function or usage.
+
 Send enquiries to osita@protein-science.com
 """
 import numpy as np
@@ -161,7 +165,8 @@ def addBackbone(N, CA, C, atmpos, psi):
         for i in di:
             O = calcCoordinate(N,CA,C,1.23,120.5,i)
             if calcDistance(O,atmpos[0]) > 2.0:
-                break                        
+                break   
+                                     
     elif psi > 0 and psi < 100:
         di = [-140,140,-30,40]
         for i in di:
@@ -220,7 +225,6 @@ def repairSer(atoms,coord,resNo,chain,missing,faspr,nextres='',psi=''):
     if FASPR PDB is not provided. If atoms that are missing do not require 
     flexible chi, FASPR is not needed. All constraints (bond/di angle, bond
     length are taken from Dunbrack 2011 rotamer library. 
-    Thanks to Tien et al. who extracted the data (Tien et al. PeerJ, 2013)
 
     Arguments
     ----------
@@ -259,7 +263,7 @@ def repairSer(atoms,coord,resNo,chain,missing,faspr,nextres='',psi=''):
     else:
         N_CA_CB_OG_diangle = -63.3
 
-    # for SER, fixing OG1, requires flexible chi
+    # for SER, fixing OG, requires flexible chi
     require_chi = ['OG']
 
     for i in missing:
