@@ -1,6 +1,10 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
+Print(functionName.__doc__) to see the 
+
+documentation for the function or usage.
+
 Send enquiries to osita@protein-science.com
 """
 import copy
@@ -8,13 +12,13 @@ from . import LinearAlgebra
 from math import sqrt
 from . import PotentialEnergy 
 
-def arginine(ires,i="",nextres=None):
+def arginine_h(ires,i="",nextres=None):
     """
     This function plus the next 19 represent 20 amino acid residues.
     Annotation is provided in detail here only  b/c all the 
     functions are essentially the same, that is, they take 
     similar arguments except SER, THR, TYR and free CYS that have class6 H-atoms
-    to be optimized with a potential energy function. The last 3 functions
+    to be optimized with a potential energy function. The last 4 functions
     are different from these 20 and annotations are provided
 
     This function adds missing hydrogen atoms of the ARG residue.
@@ -90,7 +94,7 @@ def arginine(ires,i="",nextres=None):
     return coord_copy, atoms_copy
 
 
-def isoleucine(ires,i="",nextres=None):
+def isoleucine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the ILE residue.
@@ -142,7 +146,7 @@ def isoleucine(ires,i="",nextres=None):
     coord_copy.extend([HA,HB,HG11,HG12,HG21,HG22,HG23,HD1,HD2,HD3])
     return coord_copy, atoms_copy
 
-def leucine(ires,i="",nextres=None):
+def leucine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the LEU residue.
@@ -194,7 +198,7 @@ def leucine(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2,HG,HD11,HD12,HD13,HD21,HD22,HD23])
     return coord_copy, atoms_copy
 
-def tryptophan(ires,i="",nextres=None):
+def tryptophan_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the TRP residue.
@@ -250,7 +254,7 @@ def tryptophan(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2,HD1,HE1,HE3,HZ2,HZ3,HH2])
     return coord_copy, atoms_copy
 
-def phenylalanine(ires,i="",nextres=None):
+def phenylalanine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the PHE residue.
@@ -301,7 +305,7 @@ def phenylalanine(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2,HD1,HD2,HE1,HE2,HZ])
     return coord_copy, atoms_copy
 
-def asparagine(ires,i="",nextres=None):
+def asparagine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the ASN residue.
@@ -343,7 +347,7 @@ def asparagine(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2,HD12,HD22])
     return coord_copy, atoms_copy
 
-def alanine(ires,i="",nextres=None):
+def alanine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the ALA residue.
@@ -381,7 +385,7 @@ def alanine(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2,HB3])
     return coord_copy, atoms_copy
 
-def glycine(ires,i="",nextres=None):
+def glycine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the GLY residue.
@@ -412,7 +416,7 @@ def glycine(ires,i="",nextres=None):
     coord_copy.extend([HA1,HA2])
     return coord_copy, atoms_copy
 
-def valine(ires,i="",nextres=None):
+def valine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the VAL residue.
@@ -461,7 +465,7 @@ def valine(ires,i="",nextres=None):
     coord_copy.extend([HA,HB,HG11,HG12,HG13,HG21,HG22,HG23])
     return coord_copy, atoms_copy
 
-def lysine(ires,i="",nextres=None):
+def lysine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the LYS residue.
@@ -512,7 +516,7 @@ def lysine(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2,HG1,HG2,HD1,HD2,HE1,HE2,HZ1,HZ2,HZ3])
     return coord_copy, atoms_copy
 
-def aspartate(ires,i="",nextres=None):
+def aspartate_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the ASP residue.
@@ -550,7 +554,7 @@ def aspartate(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2])
     return coord_copy, atoms_copy
 
-def glutamine(ires,i="",nextres=None):
+def glutamine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the GLN residue.
@@ -595,7 +599,7 @@ def glutamine(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2,HG1,HG2,HE21,HE22])
     return coord_copy, atoms_copy
 
-def glutamate(ires,i="",nextres=None):
+def glutamate_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the GLU residue.
@@ -636,7 +640,7 @@ def glutamate(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2,HG1,HG2])
     return coord_copy, atoms_copy
 
-def histidine(ires,i="",nextres=None):
+def histidine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the HIS residue.
@@ -682,7 +686,7 @@ def histidine(ires,i="",nextres=None):
     coord_copy.extend([HA,HB1,HB2,HD2,HE1,HE2])
     return coord_copy, atoms_copy
 
-def proline(ires,i="",nextres=None):
+def proline_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the PRO residue.
@@ -725,7 +729,7 @@ def proline(ires,i="",nextres=None):
     return coord_copy, atoms_copy
 
 
-def metheonine(ires,i="",nextres=None):
+def metheonine_h(ires,i="",nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the MET residue.
@@ -852,7 +856,7 @@ def notDisulfide(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
         coord_copy.extend([HA,HB1,HB2,HG])
         return coord_copy, atoms_copy
 
-def threonine(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
+def threonine_h(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the THR residue.
@@ -905,7 +909,7 @@ def threonine(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
     return coord_copy, atoms_copy
 
 
-def serine(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
+def serine_h(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the SER residue.
@@ -950,7 +954,7 @@ def serine(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
     return coord_copy, atoms_copy
 
 
-def tyrosine(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
+def tyrosine_h(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
     """
     This function adds missing hydrogen 
     atoms of the TYR residue.
@@ -1029,7 +1033,7 @@ def checkDisulfide(sg_i,coord):
 
     return 'not_bond'
 
-def ntermini_notPro(ires,resn2):
+def ntermini_notpro(ires,resn2):
     """
     This function will generate N-ter hydrogens if it is not a PRO.
 
@@ -1063,7 +1067,7 @@ def ntermini_notPro(ires,resn2):
 
     return [H1,H2,H3]
 
-def ntermini_Pro(ires,resn2):
+def ntermini_pro(ires,resn2):
     """
     This function will generate N-ter hydrogens if it is a PRO.
 
@@ -1085,4 +1089,18 @@ def ntermini_Pro(ires,resn2):
 
     H1,H2 = LinearAlgebra.class2(pos_CA,pos_CD,pos_N,1.01)
 
-    return [H1,H2]
\ No newline at end of file
+    return [H1,H2]
+
+def his_prot(ires):
+    """
+    This function adds missing hydrogen 
+    atoms of the HIS residue.
+    See arginine() for full annotation
+    """
+    atoms,coord= ires[1], ires[2]
+    pos_CG     = coord[atoms.index('CG')]
+    pos_ND1    = coord[atoms.index('ND1')]
+    pos_CE1    = coord[atoms.index('CE1')]
+
+    HD1        =  LinearAlgebra.class5(pos_CE1,pos_ND1,pos_CG,1.01)
+    return [HD1]
\ No newline at end of file
