@@ -1,15 +1,39 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
+Print(functionName.__doc__) to see the 
+
+documentation for the function or usage.
+
 Send enquiries to osita@protein-science.com
 """
 import os
 import sys
-import string
 import itertools
 from .MissingHydrogenAtoms import *
 from .CheckPDBatoms import checkpdbAtoms
 
+def his_note(resNo, chainNo):
+    """
+    This function informs user
+    whenever HIS is protonated
+    on both delta and epsilon N
+    
+    Arguments
+    ----------
+    resNo:   the residue number
+
+    chainNo: the chain number
+    
+    Returns
+    -------
+    None:   writes to a log.txt file
+     
+    """
+    with open('log.txt', 'a') as f:
+        f.write('HIS {} in chain {} is protonated (+1 charge)'\
+        .format(resNo,chainNo)+'\n\n')
+
 def atomType(name):
     """
     This function returns the
@@ -59,14 +83,14 @@ def insertRes(res):
 
 def repairPDB(pdb_pras,rotamer,mutation,pdb_faspr):
     """
-    This function steps over each residue of a chain and returns
-    all atoms of the residue to be wrttien to a new PDB file.
+    This function steps over each residue of a chain and obtains from
+    MissingHydrogenAtoms.py all atoms of the residue to be wrttien to a new PDB file.
 
-    If the residue is not the last and the next residue is not PRO it 
-    returns backbone H otherwise it returns no backbone H. 
+    If the residue is not the last and the next residue is not PRO the returned list 
+    will contain a backbone H otherwise it will have no backbone H. 
 
     For Cys residue, SG_coords are used to check for disulfide bonds.
-    If disulfide bond exits it returns no HG, otherwise it returns HG
+    If disulfide bond exists it obtains no HG, otherwise it obtains HG
     
     Arguments (this function takes 4 compulsory arguments)
     ----------
@@ -113,10 +137,6 @@ def repairPDB(pdb_pras,rotamer,mutation,pdb_faspr):
     nchains = checkpdbAtoms(pdb_pras,rotamer,mutation,pdb_faspr) 
     chains = list(itertools.chain(*[i[-1] for i in nchains]))
 
-    # Some PDB files have named and unamed chains
-    # if there is an unamed chain ignore the naming.
-    if len(chains) != len(nchains):                                              
-        chains = list(string.ascii_uppercase[0:len(nchains)])
     # atom numbering starts from the first chain
     number=1 
     for n in range(len(nchains)):
@@ -131,130 +151,130 @@ def repairPDB(pdb_pras,rotamer,mutation,pdb_faspr):
         for i,j in  enumerate(x): 
             if j[0].startswith('ARG'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name = arginine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name = arginine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name = arginine(x[i])
+                    apos,name = arginine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('ALA'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=alanine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=alanine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=alanine(x[i])
+                    apos,name=alanine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('ASP'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=aspartate(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=aspartate_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=aspartate(x[i])
+                    apos,name=aspartate_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('ASN'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=asparagine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=asparagine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=asparagine(x[i])
+                    apos,name=asparagine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('GLU'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=glutamate(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=glutamate_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=glutamate(x[i])
+                    apos,name=glutamate_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('GLN'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=glutamine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=glutamine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=glutamine(x[i])
+                    apos,name=glutamine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('GLY'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=glycine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=glycine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=glycine(x[i])
+                    apos,name=glycine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('HIS'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=histidine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=histidine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=histidine(x[i])
+                    apos,name=histidine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('ILE'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=isoleucine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=isoleucine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=isoleucine(x[i])
+                    apos,name=isoleucine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('LEU'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=leucine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=leucine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=leucine(x[i])
+                    apos,name=leucine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('LYS'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=lysine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=lysine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=lysine(x[i])
+                    apos,name=lysine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('MET'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=metheonine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=metheonine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=metheonine(x[i])
+                    apos,name=metheonine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('PRO'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=proline(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=proline_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=proline(x[i])
+                    apos,name=proline_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('TRP'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=tryptophan(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=tryptophan_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=tryptophan(x[i])
+                    apos,name=tryptophan_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('VAL'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=valine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=valine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=valine(x[i])
+                    apos,name=valine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('PHE'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=phenylalanine(x[i],i,x[(i+1)%len(x)])
+                    apos,hpos,name=phenylalanine_h(x[i],i,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=phenylalanine(x[i])
+                    apos,name=phenylalanine_h(x[i])
                     res_pos.extend([apos]);atom_name.extend([name])
 
                     """
@@ -270,26 +290,26 @@ def repairPDB(pdb_pras,rotamer,mutation,pdb_faspr):
                     """
             elif j[0].startswith('SER'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=serine(x[i],i,resNo[i],atom,atmpos,resNo,resseq,x[(i+1)%len(x)])
+                    apos,hpos,name=serine_h(x[i],i,resNo[i],atom,atmpos,resNo,resseq,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=serine(x[i],i,resNo[i],atom,atmpos,resNo,resseq)
+                    apos,name=serine_h(x[i],i,resNo[i],atom,atmpos,resNo,resseq)
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('THR'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=threonine(x[i],i,resNo[i],atom,atmpos,resNo,resseq,x[(i+1)%len(x)])
+                    apos,hpos,name=threonine_h(x[i],i,resNo[i],atom,atmpos,resNo,resseq,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=threonine(x[i],i,resNo[i],atom,atmpos,resNo,resseq)
+                    apos,name=threonine_h(x[i],i,resNo[i],atom,atmpos,resNo,resseq)
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('TYR'):
                 if x[(i+1)% len(x)][0][:3] != 'PRO' and x[i] != x[-1]:
-                    apos,hpos,name=tyrosine(x[i],i,resNo[i],atom,atmpos,resNo,resseq,x[(i+1)%len(x)])
+                    apos,hpos,name=tyrosine_h(x[i],i,resNo[i],atom,atmpos,resNo,resseq,x[(i+1)%len(x)])
                     res_pos.extend([apos]);h_pos.extend([hpos]);atom_name.extend([name])
                 else:
-                    apos,name=tyrosine(x[i],i,resNo[i],atom,atmpos,resNo,resseq)
+                    apos,name=tyrosine_h(x[i],i,resNo[i],atom,atmpos,resNo,resseq)
                     res_pos.extend([apos]);atom_name.extend([name])
 
             elif j[0].startswith('CYS'):
@@ -309,6 +329,17 @@ def repairPDB(pdb_pras,rotamer,mutation,pdb_faspr):
                         res_pos.extend([apos])
                         atom_name.extend([name])
 
+        #check HIS protonation
+        his = [j for i,j in enumerate(x) if x[i][0][:3] == 'HIS']
+        if len(his) <= 4:
+            pass
+        else:
+            prot = len(his)//5
+            for i in range(prot):
+                res_pos[int(his[i][0][3:])-1].extend(his_prot(his[i]))
+                atom_name[int(his[i][0][3:])-1].extend(['HD1'])
+                his_note(int(his[i][0][3:]),n+1)
+
         # Add backbone hydrogen. 
         # It belongs to resi i+1
         for i,j in enumerate(h_pos):
@@ -318,10 +349,10 @@ def repairPDB(pdb_pras,rotamer,mutation,pdb_faspr):
         # Add n-terminal hydrogen, if proline only two H
         # If not PRO, three H
         if x[0][0][:3] == 'PRO':
-            res_pos[0].extend(ntermini_Pro(x[0],resn[0][:3]))
+            res_pos[0].extend(ntermini_pro(x[0],resn[0][:3]))
             atom_name[0].extend(['H1','H2'])
         else:
-            res_pos[0].extend(ntermini_notPro(x[0],resn[0][:3]))
+            res_pos[0].extend(ntermini_notpro(x[0],resn[0][:3]))
             atom_name[0].extend(['H1','H2','H3'])
         
         # steps over each residue
