@@ -1,6 +1,10 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
+Print(functionName.__doc__) to see the 
+
+documentation for the function or usage.
+
 Send enquiries to osita@protein-science.com
 """
 import itertools
@@ -28,6 +32,8 @@ def ramachandranTypes(filename, cmap = ""):
 	----------
 	filename: PRAS generated PDB file
 
+	cmap    : Colour for the plot (e.g, viridis,magma,inferno,jet,plasma)
+
 	Returns
 	-------
 	None:  plots 4 types of  Ramanchandran in TIF format
